import logging
import yaml

logging.basicConfig()
logging.getLogger().setLevel(logging.DEBUG)

# But you can use your content.


def parse_file(filename):
    logging.debug(f"opening {filename}")
    with open(filename) as f:
        lines = f.readlines()
        titles = [f"# {x[6:].strip()[1:-1]}\n" for x in lines if x.startswith("title:")]
        entries = titles + [f"#{x}" for x in lines if x[0] == "#"]
        entries = [f"* {x[4:]}" if x[:4] == "###" else x for x in entries]
    return entries


summary_header = """---
title: "Lecture Overview"
---
"""


def generate_summary():
    project_config = yaml.safe_load(open("_quarto.yml"))

    files = [
        fn
        for s in project_config["website"]["sidebar"]["contents"]
        if s.get("section") == "Lectures"
        for fn in s["contents"] or []
    ]

    all_entries = []
    for x in files:
        all_entries.extend(parse_file(x))

    with open("summary.qmd", "w") as outfile:
        outfile.write(summary_header)
        outfile.writelines(all_entries)


def main():
    generate_summary()


if __name__ == "__main__":
    exit(main())
